summaryrefslogtreecommitdiffstats
path: root/kword/KWTextFrameSet.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-15 15:32:11 -0600
committerTimothy Pearson <[email protected]>2011-12-15 15:32:11 -0600
commit94844816550ad672ccfcdc25659c625546239998 (patch)
treee35fc60fd736c645d59f6408af032774ad8023d3 /kword/KWTextFrameSet.h
parent2a811c38c74c03648ecf857e566c44483cbad706 (diff)
downloadkoffice-94844816550ad672ccfcdc25659c625546239998.tar.gz
koffice-94844816550ad672ccfcdc25659c625546239998.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kword/KWTextFrameSet.h')
-rw-r--r--kword/KWTextFrameSet.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kword/KWTextFrameSet.h b/kword/KWTextFrameSet.h
index ef83a3c8..aee28007 100644
--- a/kword/KWTextFrameSet.h
+++ b/kword/KWTextFrameSet.h
@@ -93,14 +93,14 @@ public:
void clearUndoRedoInfo();
/** Convert the @p dPoint in the normal coordinate system (and in pt)
* into a point (@p iPoint) in the internal qtextdoc coordinates (in tqlayout units). */
KWFrame * documentToInternal( const KoPoint &dPoint, TQPoint &iPoint ) const;
/// used by documentToInternalMouseSelection()
enum RelativePosition { InsideFrame, LeftOfFrame, TopOfFrame, AtEnd };
KWFrame * documentToInternalMouseSelection( const KoPoint &dPoint, TQPoint &iPoint, RelativePosition& relPos, KWViewMode *viewMode ) const;
/** Convert the @p in the internal qtextdoc coordinates (in tqlayout units)
* into a point in the document coordinate system (in pt).
* Also returns the frame in which this point is. */
KWFrame * internalToDocument( const KoPoint &relPoint, KoPoint &dPoint ) const;
@@ -125,7 +125,7 @@ public:
KoPoint internalToDocumentKnowingFrame( const TQPoint &iPoint, KWFrame* theFrame ) const;
/** Implementation of Ctrl+PageUp/PageDown
* Returns a point in tqlayout units (for placing the cursor) */
TQPoint moveToPage( int currentPgNum, short int direction ) const;
/** Return the available height in pixels (sum of all frames' height, with zoom applied)
@@ -215,8 +215,8 @@ public:
void findPosition( const KoPoint &dPoint, KoTextParag * & parag, int & index );
/** Highlighting support (for search/replace, spellchecking etc.) */
- void highlightPortion( KoTextParag * parag, int index, int length, KWCanvas * canvas, bool tqrepaint = true, KDialogBase* dialog = 0 );
- void removeHighlight( bool tqrepaint = true );
+ void highlightPortion( KoTextParag * parag, int index, int length, KWCanvas * canvas, bool repaint = true, KDialogBase* dialog = 0 );
+ void removeHighlight( bool repaint = true );
virtual void addTextFrameSets( TQPtrList<KWTextFrameSet> &lst, bool onlyReadWrite=false );
@@ -237,9 +237,9 @@ public:
#endif
/** Invalidate all paragraphs and start re-formatting */
- virtual void tqlayout();
+ virtual void layout();
/** Invalidate all paragraphs (causes a re-flow of the text upon next redraw) */
- virtual void tqinvalidate();
+ virtual void invalidate();
virtual int paragraphs();
virtual int paragraphsSelected();
@@ -275,19 +275,19 @@ public:
/** Let KoTextFormatInterface set the modified format */
virtual KCommand *setFormatCommand( const KoTextFormat * newFormat, int flags, bool zoomFont = false );
/** Let KoTextFormatInterface access the current parag tqlayout */
virtual const KoParagLayout * currentParagLayoutFormat() const;
virtual bool rtl() const ;
- /** Let KoTextFormatInterface set a modified current parag tqlayout */
+ /** Let KoTextFormatInterface set a modified current parag layout */
virtual KCommand *setParagLayoutFormatCommand( KoParagLayout *newLayout, int flags, int marginIndex=-1);
virtual KCommand *setChangeCaseOfTextCommand(KoChangeCaseDia::TypeOfCase _type);
/** (Assuming this==main frameset), recalc the foot note numbers */
- void renumberFootNotes( bool tqrepaint = true );
+ void renumberFootNotes( bool repaint = true );
/**
* Iteration over text objects - used by KWBgSpellCheck
@@ -93,14 +93,14 @@ public:
void clearUndoRedoInfo();
/** Convert the @p dPoint in the normal coordinate system (and in pt)
- * into a point (@p iPoint) in the internal qtextdoc coordinates (in tqlayout units). */
+ * into a point (@p iPoint) in the internal qtextdoc coordinates (in layout units). */
KWFrame * documentToInternal( const KoPoint &dPoint, TQPoint &iPoint ) const;
/// used by documentToInternalMouseSelection()
@@ -93,14 +93,14 @@ public:
enum RelativePosition { InsideFrame, LeftOfFrame, TopOfFrame, AtEnd };
KWFrame * documentToInternalMouseSelection( const KoPoint &dPoint, TQPoint &iPoint, RelativePosition& relPos, KWViewMode *viewMode ) const;
- /** Convert the @p in the internal qtextdoc coordinates (in tqlayout units)
+ /** Convert the @p in the internal qtextdoc coordinates (in layout units)
* into a point in the document coordinate system (in pt).
* Also returns the frame in which this point is. */
@@ -125,7 +125,7 @@ public:
KoPoint internalToDocumentKnowingFrame( const TQPoint &iPoint, KWFrame* theFrame ) const;
/** Implementation of Ctrl+PageUp/PageDown
- * Returns a point in tqlayout units (for placing the cursor) */
+ * Returns a point in layout units (for placing the cursor) */
TQPoint moveToPage( int currentPgNum, short int direction ) const;
/** Return the available height in pixels (sum of all frames' height, with zoom applied)
@@ -275,19 +275,19 @@ public:
/** Let KoTextFormatInterface set the modified format */
virtual KCommand *setFormatCommand( const KoTextFormat * newFormat, int flags, bool zoomFont = false );
- /** Let KoTextFormatInterface access the current parag tqlayout */
+ /** Let KoTextFormatInterface access the current parag layout */
virtual const KoParagLayout * currentParagLayoutFormat() const;
virtual bool rtl() const ;